/*
 * Pluginsystem
 * Copyright (C) Thasso Griebel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package org.java.plugin.extension.annotations.scanner.archiveiterator;

import java.io.InputStream;
import java.io.IOException;

/**
 * Delegate to everything but close().  This object will not close the stream
 *
 * Code is boroght from
 * <a href="http://bill.burkecentral.com/2008/01/14/scanning-java-annotations-at-runtime/">
 * http://bill.burkecentral.com/2008/01/14/scanning-java-annotations-at-runtime/
 * </a>
 * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
 * @version $Revision: 1 $
 */
public class InputStreamWrapper extends InputStream
{
   private InputStream delegate;

   public InputStreamWrapper(InputStream delegate)
   {
      this.delegate = delegate;
   }

   public int read()
           throws IOException
   {
      return delegate.read();
   }

   public int read(byte[] bytes)
           throws IOException
   {
      return delegate.read(bytes);
   }

   public int read(byte[] bytes, int i, int i1)
           throws IOException
   {
      return delegate.read(bytes, i, i1);
   }

   public long skip(long l)
           throws IOException
   {
      return delegate.skip(l);
   }

   public int available()
           throws IOException
   {
      return delegate.available();
   }

   public void close()
           throws IOException
   {
      // ignored
   }

   public void mark(int i)
   {
      delegate.mark(i);
   }

   public void reset()
           throws IOException
   {
      delegate.reset();
   }

   public boolean markSupported()
   {
      return delegate.markSupported();
   }
}
