/*
 * Pluginsystem
 * Copyright (C) Thasso Griebel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package org.java.plugin.extension.annotations.scanner.archiveiterator;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.jar.JarEntry;
import java.util.jar.JarInputStream;

/**
 * Code is boroght from
 * <a href="http://bill.burkecentral.com/2008/01/14/scanning-java-annotations-at-runtime/">
 * http://bill.burkecentral.com/2008/01/14/scanning-java-annotations-at-runtime/
 * </a>
 * @author <a href="mailto:bill@burkecentral.com">Bill Burke</a>
 * @version $Revision: 1 $
 */
public class JarIterator implements StreamIterator
{
   JarInputStream jar;
   JarEntry next;
   Filter filter;
   boolean initial = true;
   boolean closed = false;

   public JarIterator(File file, Filter filter) throws IOException
   {
      this(new FileInputStream(file), filter);
   }


   public JarIterator(InputStream is, Filter filter) throws IOException
   {
      this.filter = filter;
      jar = new JarInputStream(is);
   }

   private void setNext()
   {
      initial = true;
      try
      {
         if (next != null) jar.closeEntry();
         next = null;
         do
         {
            next = jar.getNextJarEntry();
         } while (next != null && (next.isDirectory() || (filter == null || !filter.accepts(next.getName()))));
         if (next == null)
         {
            close();
         }
      }
      catch (IOException e)
      {
         throw new RuntimeException("failed to browse jar", e);
      }
   }

   public InputStream next()
   {
      if (closed || (next == null && !initial)) return null;
      setNext();
      if (next == null) return null;
      return new InputStreamWrapper(jar);
   }

   public void close()
   {
      try
      {
         closed = true;
         jar.close();
      }
      catch (IOException ignored)
      {

      }

   }
}
