/*
 * Pluginsystem
 * Copyright (C) Thasso Griebel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package org.java.plugin.extension.converter;

import com.google.inject.spi.TypeConverter;
import com.google.inject.TypeLiteral;


/**
 * Implementations convert from source to target type.
 * <p>
 * This interface is supported by an ExtensionPoint "PluginSystem@Converter". If
 * you want to use the {@code @Extension} annotation, consider implementing {@link org.java.plugin.extension.converter.ExtendedConverter}
 * otherwise you have to specify source and target parameters using data type Strings that can be parsed by the
 * {@link org.java.plugin.extension.converter.TypeConverter}
 *
 *
 * @author Thasso Griebel (thasso.griebel@gmail.com)
 */
public interface Converter<Source, Target> {

    /**
     * Converts the given source object to target type using the given classloader
     * to resolve any resources.
     *
     * @param source the source value
     * @param loader the loader
     * @return converted result
     */
    Target convert(Source source, ClassLoader loader);
}
