/*
 * Pluginsystem
 * Copyright (C) Thasso Griebel
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package org.java.plugin.extension.converter;

import java.util.List;

/**
 * A pipeline of converters executed sequencially passing on the results.
 *
 * @author Thasso Griebel (thasso.griebel@gmail.com)
 */
class PipedConverter implements Converter {
    /**
     * List of converter
     */
    private List<Converter> converters;

    /**
     * Create a new PipedConverter
     *
     * @param converters piped converters
     */
    PipedConverter(List<Converter> converters) {
        if(converters == null) throw new NullPointerException();
        if(converters.size() == 0) throw new IllegalArgumentException();
        this.converters = converters;
    }

    /**
     * Converts given source to a target using the defined pipeline of converters
     *
     * @param source the source value
     * @param loader the loader
     * @return result
     */
    public Object convert(final Object source, final ClassLoader loader) {
        Object tmpSrc = source;
        for (Converter converter : converters) {
            tmpSrc = converter.convert(tmpSrc,loader);
        }
        return tmpSrc;
    }

    @Override
    public String toString() {
        return "PipedConverter of " + converters;
    }
}
