package org.java.plugin.registry.xml;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import org.java.plugin.registry.Documentation;
import org.java.plugin.registry.PluginDescriptor;
import org.java.plugin.registry.PluginFragment;
import org.java.plugin.registry.Version;


/**
 * Implementation if {@link org.java.plugin.registry.Library} used to be able to
 * add default library location for plugins.
 *
 * @see org.java.plugin.registry.xml.PluginDescriptorImpl
 */
class LibraryExplicit implements org.java.plugin.registry.Library{

	private String path;
	private PluginDescriptor plugin;
	private List<String> exports;
	private boolean isCodeLibrary;
	private String id;

	LibraryExplicit(String id, String path, PluginDescriptor plugin, boolean isCodeLib){
		this(id, path, plugin, new String[]{"*"}, isCodeLib);
	}

	LibraryExplicit(String id, String path, PluginDescriptor plugin){
		this(id, path, plugin, new String[]{"*"});
	}
	
	LibraryExplicit(String id, String path, PluginDescriptor plugin, String[] exports){
		this(id, path, plugin, exports, true);
	}
	
	LibraryExplicit(String id, String path, PluginDescriptor plugin, String[] exports, boolean isCodeLib){
		super();
		this.id = id;
		this.path = path;
		this.plugin = plugin;
		this.exports = Arrays.asList(exports);
		this.isCodeLibrary = isCodeLib;
	}

    public Collection<String> getExports() {
		return exports;
	}

	public String getPath() {
		return path;
	}

	public Version getVersion() {
		return null;
	}

	public boolean isCodeLibrary() {
		return isCodeLibrary;
	}

	public String getUniqueId() {
		return plugin.getId()+"@"+getId();
	}

	public String getId() {
		return id;
	}

	public PluginDescriptor getDeclaringPluginDescriptor() {
		return plugin;
	}

	public PluginFragment getDeclaringPluginFragment() {
		return null;
	}

	public String getDocsPath() {
		return null;
	}
	public Documentation<org.java.plugin.registry.Library> getDocumentation() {
		return null;
	}
}
